**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Name             modelEco_cashFlow_rateTax.gms
Sequence         2 - The farm model
Type             LP
GAMS language     increase a SET in a variable

Description
Added gross margin calculation
"A given farmer can grow wheat, sugar beet and barley.
He has 100 ha and must determine the area dedicated to each crop, knowing that he wants to maximize his income.
The fixed costs of his farm amount to 30500 allocated monthly. His initial cashflow amounts to 20000.
Every month he withdraws 2000 for his personal income.

His monthly costs per crop (phytosanitary products, material, fuel, maintenance, and fertilizer) are as follows :

Monthly costs per crop ()
Month        M1       M2       M3        M4        M5        M6        M7        M8        M9        M10        M11     M12
Wheat        0        10      130        90        10        10        0        210        0         110        0        0
sugar beet   0        0        10       330        30        10        10        0        110        370       10        15
Barley       0        10      130        90        10        10        0        200        0         110        0        0

Wheat and barley are sold the month following the harvest (M8), in September (M9) at the price of 17/q and 14/q, respectively.
Sugar beet is grown under contract and the payment is made in December at 38/t.

Yields for wheat, sugar beet and barley are 70g/ha, 50q/ha and 72q/ha, respectively.

The farmer can borrow money from the bank on a monthly basis at an annual interest rate tax of 0. "



$Offtext
*-----------------------------------------------------------------------------*


sets
crop     /Wheat,sugar_beet,Barley/
m month  /m1*m12/
;
scalars

FIX       fixed costs                          /30500/
AIR       annual interest rate tax             /0.00/
LAND_A    land availability in hectares        /100/
;

Parameter I_LiquidA(m) initial cashflow
/m1 20000/;

Parameter Per_Salary(m) personal income
/m1*m12  2000/
;

table costs(crop,m) monthly costs per crop: phytosanitary products and material and fuel and maintenance and fertilizer
            m1   m2   m3   m4   m5   m6   m7   m8   m9  m10  m11  m12
Wheat       0   10  130   90   10   10    0   210   0  110    0    0
sugar_beet  0    0   10  330   30   10   10    0  110  370   10   15
Barley      0   10  130   90   10   10    0   200   0  110    0    0
;


parameter yields(crop)      Yields
/Wheat 70,sugar_beet 50,Barley 72/
;

table Sprice(crop,m) crop selling price
             m9    m12
Wheat       17
sugar_beet         31
Barley      14
;


variables
income
G_Margin     overall gross margin
f_expenses   financial expenses

brrw(m)      monthly borrowed amount
cash(m)      cash available per month
x(crop)      area per crop

;
positive variable
x,cash,brrw
;
equations
LAND        land equation
Calc_AM     calculation of the overall annual margin

eqcash(m)   monthly cash flow equation
Calc_finex  calculation of financial expenses
In_calc     income calculation
;
LAND..            sum(crop,x(crop))=l=LAND_A;

Calc_AM..         sum((crop,m),x(crop)*yields(crop)*Sprice(crop,m))
                  - sum((crop,m),x(crop)*costs(crop,m)) =e= G_Margin;

eqcash(m)..       I_LiquidA(m)+ sum(crop,x(crop)*yields(crop)*Sprice(crop,m))+cash(m-1)+brrw(m)=e=
                  sum(crop,x(crop)*costs(crop, m))
                  +fix/12
                  +Per_Salary(m)
                  + brrw(m)*AIR/12
                  + brrw(m-1)
                  +cash(m);

Calc_finex..      f_expenses =e= sum(m,brrw(m))*AIR/12;
In_calc..         income =e= G_Margin -fix- f_expenses ;

model modeleTreso /ALL/

SOLVE modeleTreso USING lp MAXIMIZING income;


